@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -27,7 +28,7 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 
-#include <tools/solar.h>
+#include <bf_svtools/bf_solar.h>
 
 extern "C"
 {
@@ -749,3 +750,5 @@ BOOL ExportJPEG( SvStream& rOStm, const Graphic& rGraphic, const ::com::sun::sta
     return aJPEGWriter.Write( rGraphic );
 }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
