@@ -35,11 +35,8 @@
 #include "oox/drawingml/textcharacterpropertiescontext.hxx"
 #include "oox/drawingml/fillproperties.hxx"
 #include "oox/helper/attributelist.hxx"
-#include "oox/core/namespaces.hxx"
-#include "properties.hxx"
 #include "textspacingcontext.hxx"
 #include "texttabstoplistcontext.hxx"
-#include "tokens.hxx"
 
 using ::rtl::OUString;
 using namespace ::oox::core;
@@ -188,49 +185,49 @@ Reference< XFastContextHandler > TextParagraphPropertiesContext::createFastChild
     Reference< XFastContextHandler > xRet;
     switch( aElementToken )
     {
-        case NMSP_DRAWINGML|XML_lnSpc:			// CT_TextSpacing
+        case A_TOKEN( lnSpc ):			// CT_TextSpacing
             xRet.set( new TextSpacingContext( *this, maLineSpacing ) );
             break;
-        case NMSP_DRAWINGML|XML_spcBef:			// CT_TextSpacing
+        case A_TOKEN( spcBef ):			// CT_TextSpacing
             xRet.set( new TextSpacingContext( *this, mrSpaceBefore ) );
             break;
-        case NMSP_DRAWINGML|XML_spcAft:			// CT_TextSpacing
+        case A_TOKEN( spcAft ):			// CT_TextSpacing
             xRet.set( new TextSpacingContext( *this, mrSpaceAfter ) );
             break;
 
         // EG_TextBulletColor
-        case NMSP_DRAWINGML|XML_buClrTx:		// CT_TextBulletColorFollowText ???
+        case A_TOKEN( buClrTx ):		// CT_TextBulletColorFollowText ???
             mrBulletList.mbBulletColorFollowText <<= sal_True;
             break;
-        case NMSP_DRAWINGML|XML_buClr:			// CT_Color
+        case A_TOKEN( buClr ):			// CT_Color
             xRet.set( new ColorContext( *this, *mrBulletList.maBulletColorPtr ) );
             break;
 
         // EG_TextBulletSize
-        case NMSP_DRAWINGML|XML_buSzTx:			// CT_TextBulletSizeFollowText
+        case A_TOKEN( buSzTx ):			// CT_TextBulletSizeFollowText
             mrBulletList.setBulletSize(100);
             break;
-        case NMSP_DRAWINGML|XML_buSzPct:		// CT_TextBulletSizePercent
+        case A_TOKEN( buSzPct ):		// CT_TextBulletSizePercent
             mrBulletList.setBulletSize( static_cast<sal_Int16>( GetPercent( rXAttributes->getOptionalValue( XML_val ) ) / 1000 ) );
             break;
-        case NMSP_DRAWINGML|XML_buSzPts:		// CT_TextBulletSizePoint
+        case A_TOKEN( buSzPts ):		// CT_TextBulletSizePoint
             mrBulletList.setBulletSize(0);
             mrBulletList.setFontSize( static_cast<sal_Int16>(GetTextSize( rXAttributes->getOptionalValue( XML_val ) ) ) );
             break;
 
         // EG_TextBulletTypeface
-        case NMSP_DRAWINGML|XML_buFontTx:		// CT_TextBulletTypefaceFollowText
+        case A_TOKEN( buFontTx ):		// CT_TextBulletTypefaceFollowText
             mrBulletList.mbBulletFontFollowText <<= sal_True;
             break;
-        case NMSP_DRAWINGML|XML_buFont:			// CT_TextFont
+        case A_TOKEN( buFont ):			// CT_TextFont
             mrBulletList.maBulletFont.setAttributes( aAttribs );
             break;
 
         // EG_TextBullet
-        case NMSP_DRAWINGML|XML_buNone:			// CT_TextNoBullet
+        case A_TOKEN( buNone ):			// CT_TextNoBullet
             mrBulletList.setNone();
             break;
-        case NMSP_DRAWINGML|XML_buAutoNum:		// CT_TextAutonumberBullet
+        case A_TOKEN( buAutoNum ):		// CT_TextAutonumberBullet
         {
             AttributeList attribs( rXAttributes );
             try {
@@ -253,7 +250,7 @@ Reference< XFastContextHandler > TextParagraphPropertiesContext::createFastChild
             }
             break;
         }
-        case NMSP_DRAWINGML|XML_buChar:			// CT_TextCharBullet
+        case A_TOKEN( buChar ):			// CT_TextCharBullet
             try {
                 mrBulletList.setBulletChar( rXAttributes->getValue( XML_char ) );
             }
@@ -262,17 +259,17 @@ Reference< XFastContextHandler > TextParagraphPropertiesContext::createFastChild
                 OSL_TRACE("OOX: SAXException in XML_buChar");
             }
             break;
-        case NMSP_DRAWINGML|XML_buBlip:			// CT_TextBlipBullet
+        case A_TOKEN( buBlip ):			// CT_TextBlipBullet
             {
                 mxBlipProps.reset( new BlipFillProperties );
                 xRet.set( new BlipFillContext( *this, rXAttributes, *mxBlipProps ) );
             }
             break;
 
-        case NMSP_DRAWINGML|XML_tabLst:			// CT_TextTabStopList
+        case A_TOKEN( tabLst ):			// CT_TextTabStopList
             xRet.set( new TextTabStopListContext( *this, maTabList ) );
             break;
-        case NMSP_DRAWINGML|XML_defRPr:			// CT_TextCharacterProperties
+        case A_TOKEN( defRPr ):			// CT_TextCharacterProperties
             xRet.set( new TextCharacterPropertiesContext( *this, rXAttributes, mrTextParagraphProperties.getTextCharacterProperties() ) );
             break;
     }
