@@ -43,13 +43,11 @@
 #include <com/sun/star/presentation/EffectNodeType.hpp>
 
 #include "oox/helper/attributelist.hxx"
-#include "oox/core/namespaces.hxx"
 #include "oox/core/fragmenthandler.hxx"
 #include "oox/ppt/pptimport.hxx"
 #include "oox/drawingml/drawingmltypes.hxx"
 
 #include "animationtypes.hxx"
-#include "tokens.hxx"
 
 using namespace ::oox::core;
 using namespace ::com::sun::star::uno;
@@ -520,11 +518,9 @@ static OUString getConvertedSubType( sal_Int16 nPresetClass, sal_Int32 nPresetId
 
         // ST_TLTimeNodePresetClassType
         nInt = xAttribs->getOptionalValueToken( XML_presetClass, 0 );
-        sal_Int16 nEffectPresetClass = 0;
-        sal_Int32 nPresetId = 0;
-        sal_Int32 nPresetSubType = 0;
         if( nInt != 0 )
         {
+            sal_Int16 nEffectPresetClass = 0;
             // TODO put that in a function
             switch( nInt )
             {
@@ -554,14 +550,14 @@ static OUString getConvertedSubType( sal_Int16 nPresetClass, sal_Int32 nPresetId
             aUserData[ CREATE_OUSTRING( "preset-class" ) ] = makeAny( nEffectPresetClass );
             if( attribs.hasAttribute( XML_presetID ) )
             {
-                nPresetId = attribs.getInteger( XML_presetID, 0 );
+                sal_Int32 nPresetId = attribs.getInteger( XML_presetID, 0 );
                 const preset_maping* p = gPresetMaping;
                 while( p->mpStrPresetId && ((p->mnPresetClass != nEffectPresetClass) || (p->mnPresetId != nPresetId )) )
                     p++;
 
                 aUserData[ CREATE_OUSTRING( "preset-id" ) ]
                     = makeAny( OUString::createFromAscii( p->mpStrPresetId ) );
-                nPresetSubType = attribs.getInteger( XML_presetSubtype, 0 );
+                sal_Int32 nPresetSubType = attribs.getInteger( XML_presetSubtype, 0 );
                 if( nPresetSubType )
                 {
                     aUserData[ CREATE_OUSTRING( "preset-sub-type" ) ]
@@ -620,7 +616,7 @@ static OUString getConvertedSubType( sal_Int16 nPresetClass, sal_Int32 nPresetId
 
     void SAL_CALL CommonTimeNodeContext::endFastElement( sal_Int32 aElement ) throw ( SAXException, RuntimeException)
     {
-        if( aElement == ( NMSP_PPT|XML_iterate ) )
+        if( aElement == ( PPT_TOKEN( iterate ) ) )
         {
             mbIterate = false;
         }
@@ -633,22 +629,22 @@ static OUString getConvertedSubType( sal_Int16 nPresetClass, sal_Int32 nPresetId
 
         switch ( aElementToken )
         {
-        case NMSP_PPT|XML_childTnLst:
-        case NMSP_PPT|XML_subTnLst:
+        case PPT_TOKEN( childTnLst ):
+        case PPT_TOKEN( subTnLst ):
             xRet.set( new TimeNodeListContext( *this, mpNode->getChildren() ) );
             break;
 
-        case NMSP_PPT|XML_stCondLst:
+        case PPT_TOKEN( stCondLst ):
             xRet.set( new CondListContext( *this, aElementToken, xAttribs, mpNode, mpNode->getStartCondition() ) );
             break;
-        case NMSP_PPT|XML_endCondLst:
+        case PPT_TOKEN( endCondLst ):
             xRet.set( new CondListContext( *this, aElementToken, xAttribs, mpNode, mpNode->getEndCondition() ) );
             break;
 
-        case NMSP_PPT|XML_endSync:
+        case PPT_TOKEN( endSync ):
             xRet.set( new CondContext( *this, xAttribs, mpNode, mpNode->getEndSyncValue() ) );
             break;
-        case NMSP_PPT|XML_iterate:
+        case PPT_TOKEN( iterate ):
         {
             sal_Int32 nVal = xAttribs->getOptionalValueToken( XML_type, XML_el );
             if( nVal != 0 )
@@ -681,7 +677,7 @@ static OUString getConvertedSubType( sal_Int16 nPresetClass, sal_Int32 nPresetId
             mbIterate = true;
             break;
         }
-        case NMSP_PPT|XML_tmAbs:
+        case PPT_TOKEN( tmAbs ):
             if( mbIterate )
             {
                 AttributeList attribs( xAttribs );
@@ -690,7 +686,7 @@ static OUString getConvertedSubType( sal_Int16 nPresetClass, sal_Int32 nPresetId
                 mpNode->getNodeProperties()[ NP_ITERATEINTERVAL ] <<= fTime;
             }
             break;
-        case NMSP_PPT|XML_tmPct:
+        case PPT_TOKEN( tmPct ):
             if( mbIterate )
             {
                 AttributeList attribs( xAttribs );
