@@ -46,9 +46,8 @@ namespace dmapper {
     
 using namespace ::com::sun::star;
 using namespace ::std;
-/*-- 23.04.2007 14:57:49---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
+
 DomainMapperTableManager::DomainMapperTableManager(bool bOOXML) :
     m_nRow(0),
     m_nCell(0),
@@ -67,24 +66,22 @@ DomainMapperTableManager::DomainMapperTableManager(bool bOOXML) :
 #endif
 #endif
 }
-/*-- 23.04.2007 14:57:49---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
+
 DomainMapperTableManager::~DomainMapperTableManager()
 {
     if ( m_pTablePropsHandler )
         delete m_pTablePropsHandler, m_pTablePropsHandler = NULL;
 }
-/*-- 23.04.2007 15:25:37---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
+
 bool DomainMapperTableManager::sprm(Sprm & rSprm)
 {
 #ifdef DEBUG_DOMAINMAPPER
     dmapper_logger->startElement("tablemanager.sprm");
     string sSprm = rSprm.toString();
     dmapper_logger->chars(sSprm);
-    dmapper_logger->endElement("tablemanager.sprm");
+    dmapper_logger->endElement();
 #endif
     bool bRet = DomainMapperTableManager_Base_t::sprm(rSprm);
     if( !bRet )
@@ -101,13 +98,9 @@ bool DomainMapperTableManager::sprm(Sprm & rSprm)
         switch ( nSprmId )
         {
             case 0xf661: //sprmTTRLeft left table indent
-                /* WRITERFILTERSTATUS: done: 100, planned: 2, spent: 0 */
             case 0xf614: // sprmTTPreferredWidth - preferred table width
-                /* WRITERFILTERSTATUS: done: 100, planned: 2, spent: 0 */
             case NS_ooxml::LN_CT_TblPrBase_tblW:  //90722;
-                /* WRITERFILTERSTATUS: done: 100, planned: 2, spent: 0 */
             case NS_ooxml::LN_CT_TblPrBase_tblInd: //90725
-                /* WRITERFILTERSTATUS: done: 100, planned: 2, spent: 0 */
             {
                 //contains unit and value 
                 writerfilter::Reference<Properties>::Pointer_t pProperties = rSprm.getProps();
@@ -127,7 +120,7 @@ bool DomainMapperTableManager::sprm(Sprm & rSprm)
                             pPropMap->setValue( TablePropertyMap::TABLE_WIDTH, m_nTableWidth );
                     }
 #ifdef DEBUG_DOMAINMAPPER
-                    dmapper_logger->addTag(pPropMap->toTag());
+                    pPropMap->dumpXml( dmapper_logger );
 #endif
                     insertTableProps(pPropMap);
                 }
@@ -135,7 +128,6 @@ bool DomainMapperTableManager::sprm(Sprm & rSprm)
             break;
             case 0x3404:// sprmTTableHeader
             case NS_ooxml::LN_CT_TrPrBase_tblHeader: //90704  
-                /* WRITERFILTERSTATUS: done: 100, planned: 2, spent: 0 */
                 // if nIntValue == 1 then the row is a repeated header line
                 // to prevent later rows from increasing the repeating m_nHeaderRepeat is set to NULL when repeating stops
                 if( nIntValue > 0 && m_nHeaderRepeat >= 0 ) 
@@ -149,7 +141,6 @@ bool DomainMapperTableManager::sprm(Sprm & rSprm)
                     m_nHeaderRepeat = -1;
             break;  
             case 0xd608: // TDefTable
-                /* WRITERFILTERSTATUS: done: 100, planned: 2, spent: 0 */
             {    
                 writerfilter::Reference<Properties>::Pointer_t pProperties = rSprm.getProps();
                 if( pProperties.get())
@@ -180,7 +171,6 @@ bool DomainMapperTableManager::sprm(Sprm & rSprm)
             }
             break;
             case 0xD605: // sprmTTableBorders
-                /* WRITERFILTERSTATUS: done: 100, planned: 2, spent: 0 */
             {
                 writerfilter::Reference<Properties>::Pointer_t pProperties = rSprm.getProps();
                 if( pProperties.get())
@@ -195,13 +185,10 @@ bool DomainMapperTableManager::sprm(Sprm & rSprm)
             }
             break;
             case 0xd632 : //sprmTNewSpacing
-                /* WRITERFILTERSTATUS: done: 0, planned: 2, spent: 0 */
             case 0xd634 : //sprmTNewSpacing
-                /* WRITERFILTERSTATUS: done: 0, planned: 2, spent: 0 */
                 //TODO: sprms contain default (TNew) and actual border spacing of cells - not resolvable yet
             break;
             case 0xd613: //sprmTGridLineProps
-                /* WRITERFILTERSTATUS: done: 0, planned: 2, spent: 0 */
                 // TODO: needs a handler 
                 /*contains: 
                  GridLineProps">
@@ -218,7 +205,6 @@ bool DomainMapperTableManager::sprm(Sprm & rSprm)
                 */
             break;
             case 0x740a : //sprmTTlp
-                /* WRITERFILTERSTATUS: done: 0, planned: 2, spent: 0 */
                 //TODO: Table look specifier
             break;
             case 0x6816 : //unknown
@@ -228,11 +214,9 @@ bool DomainMapperTableManager::sprm(Sprm & rSprm)
             case 0x7479 : //unknown
             case 0xf617 : //unknown
             case 0xf618 : //unknown
-                /* WRITERFILTERSTATUS: done: 100, planned: 2, spent: 0 */
                 bRet = false;
             break;
             case NS_ooxml::LN_CT_TblPrBase_tblStyle: //table style name
-                /* WRITERFILTERSTATUS: done: 100, planned: 2, spent: 0 */
             {    
                 m_sTableStyleName = pValue->getString();
                 TablePropertyMapPtr pPropMap( new TablePropertyMap );
@@ -241,13 +225,11 @@ bool DomainMapperTableManager::sprm(Sprm & rSprm)
             }
             break;
             case NS_ooxml::LN_CT_TblGridBase_gridCol:
-                /* WRITERFILTERSTATUS: done: 100, planned: 2, spent: 0 */
             {   
                 getCurrentGrid()->push_back( ConversionHelper::convertTwipToMM100( nIntValue ) );
             }    
             break;
             case NS_ooxml::LN_CT_TcPrBase_vMerge : //vertical merge
-                /* WRITERFILTERSTATUS: done: 100, planned: 2, spent: 0 */
             {    
                 // values can be: LN_Value_ST_Merge_restart, LN_Value_ST_Merge_continue, in reality the second one is a 0
                 TablePropertyMapPtr pMergeProps( new TablePropertyMap );
@@ -256,24 +238,57 @@ bool DomainMapperTableManager::sprm(Sprm & rSprm)
             }
             break;
             case NS_ooxml::LN_CT_TcPrBase_gridSpan: //number of grid positions spanned by this cell
-                /* WRITERFILTERSTATUS: done: 100, planned: 2, spent: 0 */
             {    
 #if DEBUG_DOMAINMAPPER
                 dmapper_logger->startElement("tablemanager.GridSpan");
                 dmapper_logger->attribute("gridSpan", nIntValue);
-                dmapper_logger->endElement("tablemanager.GridSpan");
+                dmapper_logger->endElement();
 #endif
                 m_nGridSpan = nIntValue;
             }
             break;
             case NS_ooxml::LN_CT_TblPrBase_tblLook: 
-                /* WRITERFILTERSTATUS: done: 0, planned: 2, spent: 0 */
                 break; //todo: table look specifier
+            case NS_ooxml::LN_CT_TcPrBase_textDirection:
+            {
+                TablePropertyMapPtr pPropMap( new TablePropertyMap );
+                const sal_Int16 HORI_LEFT_TOP = 0;
+                const sal_Int16 VERT_TOP_RIGHT = 2;
+                bool bInsertCellProps = true;
+                switch ( nIntValue )
+                {
+                    case 1:  // tbRl
+                    // Binary filter takes BiDirection into account ( but I have no idea about that here )
+                    // or even what it is. But... here's where to handle it if it becomes an issue
+                        pPropMap->Insert( PROP_FRM_DIRECTION, false, uno::makeAny( VERT_TOP_RIGHT ));
+                        OSL_TRACE("Have inserted textDirection %d", nIntValue );
+                        break;
+                    case 3:  // btLr
+                        // We have to fake this text direction
+                         pPropMap->Insert( PROP_FRM_DIRECTION, false, uno::makeAny( HORI_LEFT_TOP ));
+                         pPropMap->Insert( PROP_CHAR_ROTATION, false, uno::makeAny( sal_Int16( 900 ) ));
+                        OSL_TRACE("Have inserted textDirection %d", nIntValue );
+                        break;
+                    case 4: // lrTbV
+                        pPropMap->Insert( PROP_FRM_DIRECTION, false, uno::makeAny( HORI_LEFT_TOP ));
+                        break;
+                    case 5: // tbRlV
+                        pPropMap->Insert( PROP_FRM_DIRECTION, false, uno::makeAny( VERT_TOP_RIGHT ));
+                        break;
+                    case 0: // lrTb
+                    case NS_ooxml::LN_Value_ST_TextDirection_tbLrV:
+                    default:
+                       // Ignore - we can't handle these
+                       bInsertCellProps = false;
+                       break;
+                }
+                if ( bInsertCellProps )
+                    cellProps( pPropMap );
+                break;
+            }
             case NS_ooxml::LN_CT_TcPrBase_tcW: 
-                /* WRITERFILTERSTATUS: done: 100, planned: 0.5, spent: 0 */
                 break; //fixed column width is not supported
             case NS_ooxml::LN_CT_TrPrBase_cnfStyle:
-                /* WRITERFILTERSTATUS: done: 100, planned: 0.5, spent: 0 */
                 {
                     TablePropertyMapPtr pProps( new TablePropertyMap );
                     pProps->Insert( PROP_CNF_STYLE, true, uno::makeAny( pValue->getString( ) ) );
@@ -281,11 +296,9 @@ bool DomainMapperTableManager::sprm(Sprm & rSprm)
                 }
                 break;
             case NS_ooxml::LN_CT_PPrBase_cnfStyle:
-                /* WRITERFILTERSTATUS: done: 0, planned: 0.5, spent: 0 */
                 // TODO cnfStyle on a paragraph
                 break;
             case NS_ooxml::LN_CT_TcPrBase_cnfStyle:
-                /* WRITERFILTERSTATUS: done: 100, planned: 0.5, spent: 0 */
                 {
                     TablePropertyMapPtr pProps( new TablePropertyMap );
                     pProps->Insert( PROP_CNF_STYLE, true, uno::makeAny( pValue->getString( ) ) );
@@ -335,15 +348,14 @@ void DomainMapperTableManager::endLevel( )
     dmapper_logger->startElement("dmappertablemanager.endLevel");
     PropertyMapPtr pProps = getTableProps();
     if (pProps.get() != NULL)
-        dmapper_logger->addTag(getTableProps()->toTag());
+        getTableProps()->dumpXml( dmapper_logger );
         
-    dmapper_logger->endElement("dmappertablemanager.endLevel");
+    dmapper_logger->endElement();
 #endif    
 }
 
-/*-- 02.05.2007 14:36:26---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
+
 void DomainMapperTableManager::endOfCellAction()
 {
 #ifdef DEBUG_DOMAINMAPPER
@@ -354,9 +366,8 @@ void DomainMapperTableManager::endOfCellAction()
     m_nGridSpan = 1;
     ++m_nCell;
 }
-/*-- 02.05.2007 14:36:26---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
+
 void DomainMapperTableManager::endOfRowAction()
 {
 #ifdef DEBUG_DOMAINMAPPER
@@ -377,7 +388,7 @@ void DomainMapperTableManager::endOfRowAction()
 #ifdef DEBUG_DOMAINMAPPER
             dmapper_logger->startElement("col");
             dmapper_logger->attribute("width", *aCellIter);
-            dmapper_logger->endElement("col");
+            dmapper_logger->endElement();
 #endif
             
              m_nTableWidth += *aCellIter++;
@@ -386,13 +397,12 @@ void DomainMapperTableManager::endOfRowAction()
         if( m_nTableWidth > 0)
         {
             TablePropertyMapPtr pPropMap( new TablePropertyMap );
-//            pPropMap->Insert( PROP_WIDTH, false, uno::makeAny( m_nTableWidth ));
             pPropMap->setValue( TablePropertyMap::TABLE_WIDTH, m_nTableWidth );
             insertTableProps(pPropMap);
         }
 
 #ifdef DEBUG_DOMAINMAPPER
-        dmapper_logger->endElement("tableWidth");
+        dmapper_logger->endElement();
 #endif
     }
 
@@ -413,12 +423,12 @@ void DomainMapperTableManager::endOfRowAction()
         {
             dmapper_logger->startElement("gridSpan");
             dmapper_logger->attribute("span", *aGridSpanIter);
-            dmapper_logger->endElement("gridSpan");
+            dmapper_logger->endElement();
         
             aGridSpanIter++;
         }
     }
-    dmapper_logger->endElement("gridSpans");
+    dmapper_logger->endElement();
 #endif
     
     //calculate number of used grids - it has to match the size of m_aTableGrid
@@ -461,8 +471,8 @@ void DomainMapperTableManager::endOfRowAction()
         
 #ifdef DEBUG_DOMAINMAPPER
         dmapper_logger->startElement("rowProperties");
-        dmapper_logger->addTag(pPropMap->toTag());
-        dmapper_logger->endElement("rowProperties");
+        pPropMap->dumpXml( dmapper_logger );
+        dmapper_logger->endElement();
 #endif
         insertRowProps(pPropMap);
     }
@@ -473,21 +483,19 @@ void DomainMapperTableManager::endOfRowAction()
     pCurrentSpans->clear();
     
 #ifdef DEBUG_DOMAINMAPPER
-    dmapper_logger->endElement("endOfRowAction");
+    dmapper_logger->endElement();
 #endif
 }
-/*-- 18.06.2007 10:34:37---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
+
 void DomainMapperTableManager::clearData()
 {
     m_nRow = m_nCell = m_nCellBorderIndex = m_nHeaderRepeat = m_nTableWidth = 0;
     m_sTableStyleName = ::rtl::OUString();
     m_pTableStyleTextProperies.reset();
 }
-/*-- 27.06.2007 14:19:50---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
+
 void lcl_CopyTextProperties(PropertyMapPtr pToFill,
             const StyleSheetEntry* pStyleSheetEntry, StyleSheetTablePtr pStyleSheetTable)
 {
